2025-02-12 Version: 4.7.2
- Update API ModifyApiGroup: add param RpsLimitForServerless.


2025-01-09 Version: 4.7.1
- Generated python 2016-07-14 for CloudAPI.

2025-01-09 Version: 4.7.0
- Support API ModifyInstanceVpcAttributeForConsole.
- Update API CreateLogConfig: add param CreateSlr.
- Update API DescribeApi: update response param.
- Update API DescribeApiGroup: update response param.
- Update API DescribeApiGroups: add param BasePath.
- Update API DescribeBackendInfo: update response param.
- Update API DescribeInstances: update response param.
- Update API DescribePluginsByApi: update response param.
- Update API ModifyApiGroup: add param CustomAppCodeConfig.
- Update API QueryRequestLogs: update response param.
- Update API SetDomainCertificate: add param ClientCertSDnPassThrough.
- Update API SetDomainCertificate: add param SslOcspEnable.


2025-01-07 Version: 4.6.0
- Support API ModifyInstanceVpcAttributeForConsole.
- Update API CreateLogConfig: add param CreateSlr.
- Update API DescribeApi: update response param.
- Update API DescribeApiGroup: update response param.
- Update API DescribeApiGroups: add param BasePath.
- Update API DescribeBackendInfo: update response param.
- Update API DescribeInstances: update response param.
- Update API DescribePluginsByApi: update response param.
- Update API ModifyApiGroup: add param CustomAppCodeConfig.
- Update API QueryRequestLogs: update response param.
- Update API SetDomainCertificate: add param ClientCertSDnPassThrough.
- Update API SetDomainCertificate: add param SslOcspEnable.


2024-10-19 Version: 4.5.0
- Support API AssociateInstanceWithPrivateDNS.
- Support API CreatePrivateDNS.
- Support API DeletePrivateDNS.
- Support API DissociateInstanceWithPrivateDNS.
- Support API ListPrivateDNS.
- Support API UpdatePrivateDNS.


2024-08-27 Version: 4.4.3
- Update API ModifyApiGroup: add param FilterAppCodeForBackend.


2024-08-05 Version: 4.4.2
- Generated python 2016-07-14 for CloudAPI.

2024-08-05 Version: 4.4.1
- Generated python 2016-07-14 for CloudAPI.

2024-07-19 Version: 4.4.0
- Support API ExportOAS.
- Update API DescribeBackendInfo: update param BackendId.


2024-07-19 Version: 4.4.0
- Support API ExportOAS.
- Update API DescribeBackendInfo: update param BackendId.


2024-06-13 Version: 4.3.1
- Update API DescribeAuthorizedApps: update response param.


2024-05-29 Version: 4.3.0
- Support API DescribeInstanceClusterInfo.
- Support API DescribeInstanceClusterList.


2024-05-27 Version: 4.2.1
- Update API DescribeApi: update response param.
- Update API DescribeApiDoc: update response param.
- Update API DescribeApiHistory: update response param.


2024-05-22 Version: 4.2.0
- Support API DescribeAppSecurities.


2024-05-16 Version: 4.1.0
- Support API CreateAppCode.
- Support API CreateAppKey.
- Support API DeleteAppCode.
- Support API DeleteAppKey.


2024-05-11 Version: 4.0.2
- Update API DescribeVpcAccesses: add param AccurateQuery.


2024-05-08 Version: 4.0.1
- Update API CreateAccessControlList: update response param.
- Update API DescribeAccessControlListAttribute: update response param.


2024-05-07 Version: 4.0.0
- Support API DescribeApisByVpcAccess.
- Support API ModifyApiGroupInstance.
- Support API ModifyApiGroupNetworkPolicy.
- Support API ModifyInstanceAttribute.
- Support API SetAppsAuthToApiProduct.
- Update API CreateApi: add param Tag.
- Update API CreateBackend: add param CreateSlr.
- Update API CreateBackend: add param Tag.
- Update API CreateBackend: update param CreateEventBridgeServiceLinkedRole.
- Update API CreateDataset: add param Tag.
- Update API CreateInstance: update param Duration.
- Update API CreateInstance: update param HttpsPolicy.
- Update API CreateInstance: update param PricingCycle.
- Update API CreateInstance: update response param.
- Update API CreateModel: add param Tag.
- Update API DeleteBackendModel: update param BackendModelId.
- Update API DescribeAccessControlListAttribute: update response param.
- Update API DescribeApi: update response param.
- Update API DescribeApiGroup: update response param.
- Update API DescribeApisByApp: update response param.
- Update API DescribeAuthorizedApps: update response param.
- Update API DescribeBackendInfo: update response param.
- Update API DescribeBackendList: add param Tag.
- Update API DescribeBackendList: update response param.
- Update API DescribeDatasetList: add param Tag.
- Update API DescribeDatasetList: update response param.
- Update API DescribeHistoryApis: update response param.
- Update API DescribeInstances: update response param.
- Update API DescribeModels: add param Tag.
- Update API DescribeModels: update response param.
- Update API DescribePluginApis: update response param.
- Update API DescribeVpcAccesses: add param Tag.
- Update API DescribeVpcAccesses: update response param.
- Update API ModifyApi: update param ConstantParameters.
- Update API ModifyApi: update param ErrorCodeSamples.
- Update API ModifyApi: update param FailResultSample.
- Update API ModifyApi: update param RequestParameters.
- Update API ModifyApi: update param ResultDescriptions.
- Update API ModifyApi: update param ResultSample.
- Update API ModifyApi: update param ServiceParameters.
- Update API ModifyApi: update param ServiceParametersMap.
- Update API ModifyApi: update param SystemParameters.
- Update API ModifyApiConfiguration: update param Visibility.
- Update API SetGroupAuthAppCode: update response param.
- Update API SetVpcAccess: add param Tag.
- Update API SetVpcAccess: update response param.


2023-10-25 Version: 3.1.3
- Generated python 2016-07-14 for CloudAPI.

2023-10-24 Version: 3.2.0
- Generated python 2016-07-14 for CloudAPI.

2023-10-21 Version: 3.1.1
- Generated python 2016-07-14 for CloudAPI.

2023-10-19 Version: 3.1.0
- Generated python 2016-07-14 for CloudAPI.

2023-08-11 Version: 3.0.2
- Generated python 2016-07-14 for CloudAPI.

2023-08-03 Version: 3.0.1
- Add DescribeGroupQps.

2023-07-31 Version: 3.0.0
- CreateApp add Extend parameter.
- DescribeAppAttributes add Extend parameter.
- DescribeApp add Extend parameter.
- ModifyApp add Extend parameter.

2023-06-19 Version: 2.2.20
- Republish.

2023-06-19 Version: 2.2.19
- Update DescribeApiGroup and DescribeInstances.
- Add DescribeSummaryData.

2023-05-30 Version: 2.2.18
- Modify parameter location of CreateApi.

2023-05-25 Version: 2.2.17
- Add ValidateVpcConnectivity.

2023-04-13 Version: 2.2.16
- DescribeDomain add CertificateValid date.

2023-03-23 Version: 2.2.15
- DescribeApis add tag parameter.
- CreateApp hidden parameter. 

2023-01-30 Version: 2.2.14
- Modify DescribeApis.

2022-12-05 Version: 2.2.13
- Modify QueryRequestLogs.

2022-11-29 Version: 2.2.12
- Add DescribePluginApis.
- Modify CreateApp.
- Modify DeleteApp.

2022-11-16 Version: 2.2.11
- Add ImportOAS.

2022-11-03 Version: 2.2.10
- Add QueryRequestLogs.

2022-10-13 Version: 2.2.9
- Add DatasetMethods.

2022-09-09 Version: 2.2.8
- Update SetDomainWebSocketStatus.

2022-09-02 Version: 2.2.7
- Add input parameters of DescribeApps and DescribeDeployedApis.

2022-08-29 Version: 2.2.6
- Modify  Api Ram-Meta.

2022-08-01 Version: 2.2.5
- Add parameter stageName for BatchAbolishApis.

2022-07-18 Version: 2.2.4
- Change the parameter tag to optional.

2022-07-15 Version: 2.2.3
- Add param ModifyAction.

2022-06-29 Version: 2.2.1
- Add an input param, IsHttpRedirectToHttps, of api, SetDomain.

2022-06-24 Version: 2.2.0
- Add apis for access control of instance.

2022-06-16 Version: 2.1.7
- Add response paramof api DescribeInstances.

2022-05-08 Version: 2.1.6
- Add parameter of api SetDomainCertificate.

2022-04-28 Version: 2.1.5
- Add a new api ModifyApiConfiguration.

2022-04-16 Version: 2.1.4
- Support customized host header in vpc access.

2022-03-22 Version: 2.1.3
- Support the new backend service, EventBridge.

2022-03-17 Version: 2.1.2
- Add api DetachPlugin.

2022-03-03 Version: 2.1.1
- DescribeApisByVpcAccess adds path and method of API in result.

2022-01-24 Version: 2.1.0
- Add apis for creating API by using backend service.

2021-12-31 Version: 2.0.3
- Update response parameter in DescribePlugins.
- Add query parameter vpcId, instanceId, port in DescribeVpcAccesses.

2021-12-08 Version: 2.0.2
- Add parameters in ImportSwagger and DryRun.

2021-11-23 Version: 2.0.0
- Update DescribeApisByApp.

2021-10-26 Version: 1.0.0
- Create SDK after migrating from POP to apm.

